# ha-philipsjs
Wrapper library to integrate Philips TVs with jointSPACE API into Home-Assistant

This is just being used to wrap the API into a nice object. Nothing fancy.

### Since I don't own any JointSpace TVs anymore I can't really contribute to this module anymore. If anyone would like to take the lead I'm happy to let someone else become the maintainer.
